************************
``matplotlib.colorizer``
************************

.. automodule:: matplotlib.colorizer
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members: _ColorizerInterface, _ScalarMappable
